package com.netmera.netmera_flutter_sdk;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.core.app.JobIntentService;
import android.util.Log;

import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Set;
import java.util.UUID;
import java.util.concurrent.atomic.AtomicBoolean;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.view.FlutterCallbackInformation;
import io.flutter.view.FlutterMain;
import io.flutter.view.FlutterNativeView;
import io.flutter.view.FlutterRunArguments;

/**
 * Copyright (c) 2019 Inomera Research.
 * @author Burak Soykal
 */
public class FNetmeraService extends JobIntentService implements MethodChannel.MethodCallHandler {

    private static int JOB_ID = (int) UUID.randomUUID().getMostSignificantBits();
    private static final String SERVICE_INITIALIZED = "serviceInitialized";
    private static PluginRegistry.PluginRegistrantCallback nmCallback;
    private static final AtomicBoolean serviceStarted = new AtomicBoolean(false);
    private static FlutterNativeView backgroundFlutterView = null;
    private MethodChannel backgroundChannel;

    private Context context;
    private ArrayDeque<List<Object>> queue = new ArrayDeque<>();

    public static void enqueueWork(Context context, Intent intent) {
        try{
            enqueueWork(context, FNetmeraService.class, JOB_ID, intent);
        }catch (IllegalArgumentException ex){
            Log.e("FNetmeraService","Please register FNetmeraService into manifest file");
        }

    }

    public static void setPluginRegistrant(PluginRegistry.PluginRegistrantCallback callback) {
        nmCallback = callback;
    }

    @Override
    public void onCreate() {
        super.onCreate();
        startService(this);
    }

    private void startService(Context context) {
        synchronized (serviceStarted) {
            this.context = context;
            if (backgroundFlutterView == null) {
                Long callbackHandle = getFromSharedPref(NetmeraFlutterSdkPlugin.CALLBACK_DISPATCHER_HANDLE_KEY);
                FlutterCallbackInformation callbackInfo = FlutterCallbackInformation.lookupCallbackInformation(callbackHandle);
                if(callbackInfo == null || nmCallback == null) return;
                backgroundFlutterView = new FlutterNativeView(context, true);
                nmCallback.registerWith(backgroundFlutterView.getPluginRegistry());
                FlutterRunArguments args = new FlutterRunArguments();
                args.bundlePath = FlutterMain.findAppBundlePath(context);
                args.entrypoint = callbackInfo.callbackName;
                args.libraryPath = callbackInfo.callbackLibraryPath;
                backgroundFlutterView.runFromBundle(args);
            }
        }

        backgroundChannel = new MethodChannel(backgroundFlutterView, "flutter_nm_sdk_background");
        backgroundChannel.setMethodCallHandler(this);
    }

    @Override
    protected void onHandleWork(@NonNull final Intent intent) {
        new Handler(Looper.getMainLooper()).post(
                new Runnable() {
                    @Override
                    public void run() {
                        ArrayList<Object> list = new ArrayList<>();
                        list.add(getFromSharedPref(intent.getAction()));
                        list.add(bundleToHashMap(intent.getExtras()));

                        synchronized (serviceStarted) {
                            if (!serviceStarted.get()) {
                                queue.add(list);
                            } else {
                                backgroundChannel.invokeMethod("", list);
                            }
                        }
                    }
                });
    }

    @Override
    public void onMethodCall(@NonNull final MethodCall methodCall, @NonNull final MethodChannel.Result result) {
        new Handler(Looper.getMainLooper()).post(
                new Runnable() {
                    @Override
                    public void run() {
                        if (SERVICE_INITIALIZED.equals(methodCall.method)) {
                            synchronized (serviceStarted) {
                                while (!queue.isEmpty()) {
                                    backgroundChannel.invokeMethod("", queue.remove());
                                }
                                serviceStarted.set(true);
                            }
                        }
                        result.success(null);
                    }
                });
    }

    private Long getFromSharedPref(String key) {
        return context.getSharedPreferences(
                NetmeraFlutterSdkPlugin.SHARED_PREFERENCES_KEY,
                Context.MODE_PRIVATE)
                .getLong(key, 0);
    }

    private HashMap<String, Object> bundleToHashMap(@Nullable Bundle bundle) {
        HashMap<String, Object> map = new HashMap<>();
        if (bundle == null) {
            return map;
        }
        Set<String> keys = bundle.keySet();
        for (String key : keys) {
            map.put(key, bundle.get(key));
        }
        return map;
    }
}
