package com.netmera.netmera_flutter_sdk;

import android.app.Activity;
import android.content.Context;
import androidx.annotation.NonNull;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** NetmeraFlutterSdkPlugin */
public class NetmeraFlutterSdkPlugin implements MethodCallHandler {

  private Context context;
  private Activity activity;
  static final String SHARED_PREFERENCES_KEY = "netmera_plugin_cache";
  static final String CALLBACK_DISPATCHER_HANDLE_KEY = "callback_dispatch_handler";

  private static final String INIT = "init";
  private static final String LOGGING = "logging";
  private static final String SET_BASE_URL = "setBaseUrl";
  private static final String REQUEST_PERMISSIONS_FOR_LOCATION = "requestPermissionsForLocation";
  private static final String SET_NETMERA_MAX_ACTIVE_REGIONS = "setNetmeraMaxActiveRegions";
  private static final String ENABLE_POPUP_PRESENTATION = "enablePopupPresentation";
  private static final String DISABLE_POPUP_PRESENTATION = "disablePopupPresentation";
  private static final String ENABLE_PUSH = "enablePush";
  private static final String DISABLE_PUSH = "disablePush";
  private static final String IS_PUSH_ENABLED = "isPushEnabled";
  private static final String TURN_OFF_SENDING_EVENT_AND_USER_UPDATE = "turnOffSendingEventAndUserUpdate";
  private static final String FETCH_INBOX = "fetchInbox";
  private static final String FETCH_NEXT_PAGE = "fetchNextPage";
  private static final String COUNT_FOR_STATUS = "countForStatus";
  private static final String INBOX_UPDATE_STATUS = "inboxUpdateStatus";
  private static final String SEND_EVENT = "sendEvent";
  private static final String UPDATE_USER = "updateUser";
  private static final String INIT_SERVICE = "initService";
  private static final String SET_API_KEY = "setApiKey";
  private static final String HANDLE_PUSH_OBJECT = "handlePushObject";
  private static final String TOGGLE_WEB_VIEW_PROGRESS_BAR_VISIBILITY = "toggleWebViewProgressBarVisibility";
  private static final String IS_WEB_VIEW_PROGRESS_BAR_ENABLED = "isWebViewProgressbarEnabled";

  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "netmera_flutter_sdk");
    channel.setMethodCallHandler(new NetmeraFlutterSdkPlugin(registrar));
  }

  private NetmeraFlutterSdkPlugin(Registrar registrar) {
    this.context = registrar.context();
    this.activity = registrar.activity();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    switch (call.method) {
      case INIT:
        String gcmSenderId = call.argument("gcmSenderId");
        String apiKey = call.argument("apiKey");
        FNetmera.init(context.getApplicationContext(), gcmSenderId, apiKey);
        break;
      case LOGGING:
        boolean enabled = call.argument("enabled");
        FNetmera.logging(enabled);
        break;
      case SET_BASE_URL:
        FNetmera.setBaseUrl(call);
        break;
      case REQUEST_PERMISSIONS_FOR_LOCATION:
        FNetmera.requestPermissionsForLocation();
        break;
      case SET_NETMERA_MAX_ACTIVE_REGIONS:
        FNetmera.setNetmeraMaxActiveRegions(call);
        break;
      case ENABLE_POPUP_PRESENTATION:
        FNetmera.enablePopupPresentation();
        break;
      case DISABLE_POPUP_PRESENTATION:
        FNetmera.disablePopupPresentation();
        break;
      case ENABLE_PUSH:
        FNetmera.enablePush();
        break;
      case DISABLE_PUSH:
        FNetmera.disablePush();
        break;
      case IS_PUSH_ENABLED:
        FNetmera.isPushEnabled(result);
        break;
      case TURN_OFF_SENDING_EVENT_AND_USER_UPDATE:
        FNetmera.turnOffSendingEventAndUserUpdate(call);
        break;
      case FETCH_INBOX:
        FNetmera.fetchInbox(call, result);
        break;
      case FETCH_NEXT_PAGE:
        FNetmera.fetchNextPage(result);
        break;
      case COUNT_FOR_STATUS:
        FNetmera.countForStatus(call, result);
        break;
      case INBOX_UPDATE_STATUS:
        FNetmera.inboxUpdateStatus(call, result);
        break;
      case SEND_EVENT:
        FNetmera.sendEvent(call);
        break;
      case UPDATE_USER:
        FNetmera.updateUser(call);
        break;
      case INIT_SERVICE:
        FNetmera.initializeService(context, call.arguments, result);
        break;
      case SET_API_KEY:
        FNetmera.setApiKey(call);
        break;
      case HANDLE_PUSH_OBJECT:
        FNetmera.handlePushObject(activity, call, result);
        break;
      case TOGGLE_WEB_VIEW_PROGRESS_BAR_VISIBILITY:
        FNetmera.toggleWebViewProgressBarVisibility(call);
        break;
      case IS_WEB_VIEW_PROGRESS_BAR_ENABLED:
        FNetmera.isWebViewProgressbarEnabled(result);
        break;
    }
  }
}
