# Simple showcase


`main.dart`
```

import 'dart:io';

import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/NetmeraPushBroadcastReceiver.dart';

import 'page_event.dart';
import 'page_push_inbox.dart';
import 'page_settings.dart';
import 'page_user.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
void main() {
  initBroadcastReceiver();
  runApp(MyApp());
}

void _onPushRegister(Map<dynamic, dynamic> bundle) async {
  print("onPushRegister: $bundle");
}

void _onPushReceive(Map<dynamic, dynamic> bundle) async {
  print("onPushReceive: $bundle");
}

void _onPushDismiss(Map<dynamic, dynamic> bundle) async {
  print("onPushDismiss: $bundle");
}

void _onPushOpen(Map<dynamic, dynamic> bundle) async {
  print("onPushOpen: $bundle");
}

void _onPushButtonClicked(Map<dynamic, dynamic> bundle) async {
  print("onPushButtonClicked: $bundle");
}

void initBroadcastReceiver() {
  NetmeraPushBroadcastReceiver receiver = new NetmeraPushBroadcastReceiver();
  receiver.initialize(
    onPushRegister: _onPushRegister,
    onPushReceive: _onPushReceive,
    onPushDismiss: _onPushDismiss,
    onPushOpen: _onPushOpen,
    onPushButtonClicked: _onPushButtonClicked,
  );
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();
    Netmera.logging(true);

    Netmera.isPushEnabled().then((enabled) {
      print("Netmera: isPushEnabled = " + enabled.toString());
    });

    if (Platform.isIOS) {
      Netmera.requestPushNotificationAuthorization();
      Netmera.setAppGroupName("AppGroupName");
    }

    if (Platform.isAndroid) {
      Netmera.isWebViewProgressbarEnabled().then((enabled) {
        print("Netmera: isWebViewProgressbarEnabled = " + enabled.toString());
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: DefaultTabController(
        length: 4,
        child: Scaffold(
          appBar: AppBar(
            bottom: TabBar(
              tabs: [
                Tab(icon: Text("Event")),
                Tab(icon: Text("User")),
                Tab(icon: Text("PushInbox")),
                Tab(icon: Text("Settings")),
              ],
            ),
            title: Text('NM Flutter SDK'),
          ),
          body: TabBarView(
            children: [EventPage(), UserPage(), PushInboxPage(), SettingsPage()],
          ),
        ),
      ),
    );
  }
}
```

`page-user.dart`

```
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/NetmeraUser.dart';
import 'model/MyNetmeraUser.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class UserPage extends StatefulWidget {
  @override
  _UserPageState createState() => _UserPageState();
}

class _UserPageState extends State<UserPage> {
  TextEditingController userController = TextEditingController();
  TextEditingController nameController = TextEditingController();
  TextEditingController surnameController = TextEditingController();
  TextEditingController emailController = TextEditingController();
  TextEditingController msisdnController = TextEditingController();
  String _selectedGender = NetmeraUser.GENDER_NOT_SPECIFIED.toString();

  updateUser() {
    MyNetmeraUser user = new MyNetmeraUser();
    user.setUserId(userController.text);
    user.setName(nameController.text);
    user.setSurname(surnameController.text);
    user.setEmail(emailController.text);
    user.setMsisdn(msisdnController.text);
    user.setGender(int.parse(_selectedGender));
    user.setHairColor(7);
    Netmera.updateUser(user);
  }

  List<DropdownMenuItem<String>> getGenderList() {
    List<DropdownMenuItem<String>> items = new List();
    items.add(
        new DropdownMenuItem(value: NetmeraUser.GENDER_NOT_SPECIFIED.toString(), child: new Text("NOT SPECIFIED")));
    items.add(new DropdownMenuItem(value: NetmeraUser.GENDER_MALE.toString(), child: new Text("MALE")));
    items.add(new DropdownMenuItem(value: NetmeraUser.GENDER_FEMALE.toString(), child: new Text("FEMALE")));
    return items;
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Padding(
            padding: const EdgeInsets.only(left: 50.0, right: 50.0),
            child: TextField(
              controller: userController,
              decoration: InputDecoration(labelText: 'User (Optional)'),
            ),
          ),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: nameController,
                decoration: InputDecoration(labelText: 'Name (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: surnameController,
                decoration: InputDecoration(labelText: 'Surname (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: emailController,
                decoration: InputDecoration(labelText: 'Email (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: msisdnController,
                decoration: InputDecoration(labelText: 'Msisdn (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: Row(children: [
                Text('Gender (Optional)'),
                Padding(
                    padding: const EdgeInsets.only(left: 10.0),
                    child: DropdownButton(
                        value: _selectedGender,
                        items: getGenderList(),
                        onChanged: (val) {
                          setState(() {
                            _selectedGender = val;
                          });
                        }))
              ])),
          Container(
            margin: EdgeInsets.only(top: 30),
            child: RaisedButton(
              child: Text('Update User'),
              onPressed: updateUser,
            ),
          )
        ],
      ),
    );
  }
}

```

`page-event.dart`

```
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/events/NetmeraEventLogin.dart';
import 'package:netmera_flutter_sdk/events/NetmeraEventRegister.dart';
import 'package:netmera_flutter_sdk/events/commerce/NetmeraEventCartView.dart';
import 'package:netmera_flutter_sdk/events/commerce/NetmeraEventPurchase.dart';
import 'package:netmera_flutter_sdk/events/commerce/NetmeraLineItem.dart';

import 'model/MyNetmeraEvent.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class EventPage extends StatefulWidget {
  @override
  _EventPageState createState() => _EventPageState();
}

class _EventPageState extends State<EventPage> {
  emptyAction() {}

  void sendLoginEvent() {
    NetmeraEventLogin loginEvent = new NetmeraEventLogin();
    Netmera.sendEvent(loginEvent);
  }

  void sendRegisterEvent() {
    NetmeraEventRegister registerEvent = new NetmeraEventRegister();
    Netmera.sendEvent(registerEvent);
  }

  void sendViewCartEvent() {
    NetmeraEventCartView cartViewEvent = new NetmeraEventCartView();
    cartViewEvent.setItemCount(3);
    cartViewEvent.setSubTotal(15.99);
    Netmera.sendEvent(cartViewEvent);
  }

  void purchaseEvent() {
    NetmeraLineItem netmeraLineItem = new NetmeraLineItem();
    netmeraLineItem.setBrandId("brandId12");
    netmeraLineItem.setBrandName("brandNameInomera");
    netmeraLineItem.setCampaignId("campaignId1223");
    netmeraLineItem.setCategoryIds(["categoryIds1", "categoryIds2"]);
    netmeraLineItem.setCategoryNames(["categoryNames1", "categoryNames2", "categoryNames3"]);
    netmeraLineItem.setKeywords(["keyword1", "keyword2", "keyword3"]);
    netmeraLineItem.setCount(12);
    netmeraLineItem.setId("Id123123");
    netmeraLineItem.setPrice(130);

    NetmeraEventPurchase purchaseEvent = new NetmeraEventPurchase();
    purchaseEvent.setCoupon("INOMERACODE");
    purchaseEvent.setDiscount(10);
    purchaseEvent.setItemCount(2);
    purchaseEvent.setPaymentMethod("Credit Card");
    purchaseEvent.setSubTotal(260.89);
    purchaseEvent.setShippingCost(0.0);
    purchaseEvent.setLineItems([netmeraLineItem, netmeraLineItem]);
    Netmera.sendEvent(purchaseEvent);
  }

  void sendTestEvent() {
    TestEvent1 testEvent = new TestEvent1();
    testEvent.setName("Burak");
    testEvent.setTestAttr1("testAttr1");
    Netmera.sendEvent(testEvent);
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        RaisedButton(
          child: Text('Login Event'),
          onPressed: sendLoginEvent,
        ),
        RaisedButton(
          child: Text('Register Event'),
          onPressed: sendRegisterEvent,
        ),
        RaisedButton(
          child: Text('View Cart Event'),
          onPressed: sendViewCartEvent,
        ),
        RaisedButton(
          child: Text('Purchase Event'),
          onPressed: purchaseEvent,
        ),
        RaisedButton(
          child: Text('Custom Test Event'),
          onPressed: sendTestEvent,
        ),
      ],
    );
  }
}
```

`page_push_inbox.dart`

```
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/NetmeraInboxFilter.dart';
import 'package:netmera_flutter_sdk/NetmeraPushInbox.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class PushInboxPage extends StatefulWidget {
  @override
  _PushInboxPageState createState() => _PushInboxPageState();
}

class _PushInboxPageState extends State<PushInboxPage> {
  String _currentStatus = Netmera.PUSH_OBJECT_STATUS_ALL.toString();
  String _count = "0";
  List<Widget> _inbox = List();
  List<NetmeraPushInbox> _pushInboxList = List();

  List<DropdownMenuItem<String>> getInboxList() {
    List<DropdownMenuItem<String>> items = new List();
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_ALL.toString(), child: new Text("ALL")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_READ.toString(), child: new Text("READ")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_UNREAD.toString(), child: new Text("UNREAD")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_DELETED.toString(), child: new Text("DELETED")));
    return items;
  }

  onInboxStatusChanged(String status) {
    setState(() {
      _currentStatus = status;
    });
  }

  clearInboxList() {
    setState(() {
      _inbox.clear();
    });
  }

  String getStatusText(int status) {
    switch (status) {
      case Netmera.PUSH_OBJECT_STATUS_ALL:
        return "ALL";
        break;
      case Netmera.PUSH_OBJECT_STATUS_READ:
        return "READ";
        break;
      case Netmera.PUSH_OBJECT_STATUS_UNREAD:
        return "UNREAD";
        break;
      case Netmera.PUSH_OBJECT_STATUS_DELETED:
        return "DELETED";
        break;
    }
    return "";
  }

  fillInboxList(list) {
    _pushInboxList = list;
    list.forEach((NetmeraPushInbox item) {
      setState(() {
        _inbox.add(Text(item.getTitle() + " (" + getStatusText(item.getInboxStatus()) + ")"));
      });
    });
  }

  // Click Functions
  emptyAction() {}

  getInboxFilter() {
    NetmeraInboxFilter inboxFilter = new NetmeraInboxFilter();
    inboxFilter.setPageSize(2);
    inboxFilter.setStatus(int.parse(_currentStatus));
    inboxFilter.setIncludeExpiredObjects(true);
    inboxFilter.setCategories(null);
    return inboxFilter;
  }

  fetchInbox() async {
    clearInboxList();
    Netmera.fetchInbox(getInboxFilter()).then((list) {
      fillInboxList(list);
    });
  }

  fetchNextPage() async {
    Netmera.fetchNextPage().then((list) {
      if (list.isNotEmpty) {
        clearInboxList();
      }
      fillInboxList(list);
    });
  }

  countForStatus() async {
    Netmera.countForStatus(int.parse(_currentStatus)).then((val) {
      setState(() {
        if (val != -1) {
          _count = val.toString();
        }
      });
    });
  }

  handlePushObject() async {
    if(_pushInboxList.isNotEmpty) {
      Netmera.handlePushObject(_pushInboxList[0].getPushId());
    }
  }

  inboxUpdateStatus() {
    List<String> selectedPushList = List();

    if (_pushInboxList.length > 1) {
      selectedPushList.add(_pushInboxList[0].getPushId());
      selectedPushList.add(_pushInboxList[1].getPushId());
    }

    int status = Netmera.PUSH_OBJECT_STATUS_UNREAD;

    Netmera.inboxUpdateStatus(selectedPushList, status);
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Column(
          children: _inbox,
        ),
        new DropdownButton(
          value: _currentStatus,
          items: getInboxList(),
          onChanged: onInboxStatusChanged,
        ),
        RaisedButton(
          child: Text('Fetch Inbox'),
          onPressed: fetchInbox,
        ),
        RaisedButton(
          child: Text('Fetch Next Page'),
          onPressed: fetchNextPage,
        ),
        RaisedButton(
          child: Text('Count For Status'),
          onPressed: countForStatus,
        ),
        RaisedButton(
          child: Text('Inbox Update Status (Mark first two element as Unread)'),
          onPressed: inboxUpdateStatus,
        ),
        RaisedButton(
          child: Text('Handle Push Object'),
          onPressed: handlePushObject,
        ),
        Text(
          "Count For Status:" + _count,
        )
      ],
    );
  }
}
```

`page_settings.dart`
```
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class SettingsPage extends StatefulWidget {
  @override
  _SettingsPageState createState() => _SettingsPageState();
}

class _SettingsPageState extends State<SettingsPage> {
  disablePopupPresentation() {
    Netmera.disablePopupPresentation();
  }

  enablePopupPresentation() {
    Netmera.enablePopupPresentation();
  }

  requestPermissionsForLocation() {
    Netmera.requestPermissionsForLocation();
  }

  setNetmeraMaxActiveRegions() {
    Netmera.setNetmeraMaxActiveRegions(10);
  }

  turnOffSendingEventAndUserUpdate() {
    Netmera.turnOffSendingEventAndUserUpdate(false);
  }

  toggleWebViewProgressBarVisibility() {
    Netmera.toggleWebViewProgressBarVisibility(true);
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        RaisedButton(
          child: Text('Disable Popup Presentation'),
          onPressed: disablePopupPresentation,
        ),
        RaisedButton(child: Text('Enable Popup Presentation'), onPressed: enablePopupPresentation),
        RaisedButton(
          child: Text('Request Permission For Location'),
          onPressed: requestPermissionsForLocation,
        ),
        RaisedButton(
          child: Text('Set Netmera Max Active Regions'),
          onPressed: setNetmeraMaxActiveRegions,
        ),
        RaisedButton(
          child: Text('Turn Off Sending Event And User Update'),
          onPressed: turnOffSendingEventAndUserUpdate,
        ),
        RaisedButton(
          child: Text('Toggle Web View Progress Bar Visibility (True)'),
          onPressed: toggleWebViewProgressBarVisibility,
        ),
      ],
    );
  }
}
```
