import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/NetmeraInboxFilter.dart';
import 'package:netmera_flutter_sdk/NetmeraPushInbox.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class PushInboxPage extends StatefulWidget {
  @override
  _PushInboxPageState createState() => _PushInboxPageState();
}

class _PushInboxPageState extends State<PushInboxPage> {
  String _currentStatus = Netmera.PUSH_OBJECT_STATUS_ALL.toString();
  String _count = "0";
  List<Widget> _inbox = List();
  List<NetmeraPushInbox> _pushInboxList = List();

  List<DropdownMenuItem<String>> getInboxList() {
    List<DropdownMenuItem<String>> items = new List();
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_ALL.toString(), child: new Text("ALL")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_READ.toString(), child: new Text("READ")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_UNREAD.toString(), child: new Text("UNREAD")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_DELETED.toString(), child: new Text("DELETED")));
    return items;
  }

  onInboxStatusChanged(String status) {
    setState(() {
      _currentStatus = status;
    });
  }

  clearInboxList() {
    setState(() {
      _inbox.clear();
    });
  }

  String getStatusText(int status) {
    switch (status) {
      case Netmera.PUSH_OBJECT_STATUS_ALL:
        return "ALL";
        break;
      case Netmera.PUSH_OBJECT_STATUS_READ:
        return "READ";
        break;
      case Netmera.PUSH_OBJECT_STATUS_UNREAD:
        return "UNREAD";
        break;
      case Netmera.PUSH_OBJECT_STATUS_DELETED:
        return "DELETED";
        break;
    }
    return "";
  }

  fillInboxList(list) {
    _pushInboxList = list;
    list.forEach((NetmeraPushInbox item) {
      setState(() {
        _inbox.add(Text(item.getTitle() + " (" + getStatusText(item.getInboxStatus()) + ")"));
      });
    });
  }

  // Click Functions
  emptyAction() {}

  getInboxFilter() {
    NetmeraInboxFilter inboxFilter = new NetmeraInboxFilter();
    inboxFilter.setPageSize(2);
    inboxFilter.setStatus(int.parse(_currentStatus));
    inboxFilter.setIncludeExpiredObjects(true);
    inboxFilter.setCategories(null);
    return inboxFilter;
  }

  fetchInbox() async {
    clearInboxList();
    Netmera.fetchInbox(getInboxFilter()).then((list) {
      fillInboxList(list);
    });
  }

  fetchNextPage() async {
    Netmera.fetchNextPage().then((list) {
      if (list.isNotEmpty) {
        clearInboxList();
      }
      fillInboxList(list);
    });
  }

  countForStatus() async {
    Netmera.countForStatus(int.parse(_currentStatus)).then((val) {
      setState(() {
        if (val != -1) {
          _count = val.toString();
        }
      });
    });
  }

  handlePushObject() async {
    if(_pushInboxList.isNotEmpty) {
      Netmera.handlePushObject(_pushInboxList[0].getPushId());
    }
  }

  inboxUpdateStatus() {
    List<String> selectedPushList = List();

    if (_pushInboxList.length > 1) {
      selectedPushList.add(_pushInboxList[0].getPushId());
      selectedPushList.add(_pushInboxList[1].getPushId());
    }

    int status = Netmera.PUSH_OBJECT_STATUS_UNREAD;

    Netmera.inboxUpdateStatus(selectedPushList, status);
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Column(
          children: _inbox,
        ),
        new DropdownButton(
          value: _currentStatus,
          items: getInboxList(),
          onChanged: onInboxStatusChanged,
        ),
        RaisedButton(
          child: Text('Fetch Inbox'),
          onPressed: fetchInbox,
        ),
        RaisedButton(
          child: Text('Fetch Next Page'),
          onPressed: fetchNextPage,
        ),
        RaisedButton(
          child: Text('Count For Status'),
          onPressed: countForStatus,
        ),
        RaisedButton(
          child: Text('Inbox Update Status (Mark first two element as Unread)'),
          onPressed: inboxUpdateStatus,
        ),
        RaisedButton(
          child: Text('Handle Push Object'),
          onPressed: handlePushObject,
        ),
        Text(
          "Count For Status:" + _count,
        )
      ],
    );
  }
}
